6000 Series - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# 6000 Series

From: Pico Technology

Class: `herosdevices.hardware.picotechnology.Picoscope6000a`

Driver Quality Index: beta

Requires the following packages

`picosdk-python-wrappers`

Driver class for the Picoscope 6000 series.

Note

You need the official picoscope sdk installed. Note that it is not on PyPi and you need to follow the instructions here

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.picotechnology.Picoscope6000a` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
serial_num | <class ‘str’> |  | Serial number of the picoscope. You can get that from the PicoScope GUI, it looks something like this: JP402/0012
config_dict | <class ‘dict’> |  | Dict of configuration values like shown in the json examples of the individual picoscope model drivers.
default_config | str | None | None | Default key in `config_dict` to use.

This JSON string can be used to start a HERO device representation of `Picoscope6000a` using BOSS.

    {
        "_id": "my_Picoscope6000a",
        "classname": "herosdevices.hardware.picotechnology.Picoscope6000a",
        "arguments": {
            "serial_num": "<class 'str'>",
            "config_dict": "<class 'dict'>",
            "default_config": null
        }
    }